Documentation
¶
Overview ¶
Copyright 2022 The kpt and Nephio Authors
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- Constants
- func Apply(ctx context.Context, api client.Client, obj client.Object) error
- func CreateClient(config *rest.Config) (client.Client, error)
- func CreateClientWithFlags(flags *genericclioptions.ConfigFlags) (client.Client, error)
- func CreateDynamicClient(flags *genericclioptions.ConfigFlags) (client.WithWatch, error)
- func CreateRESTClient(flags *genericclioptions.ConfigFlags) (rest.Interface, error)
- func LastSegment(path string) string
- func UpdatePackageRevisionApproval(ctx context.Context, client client.Client, pr *porchapi.PackageRevision, ...) error
Constants ¶
const ApproveErrorOut = "cannot change approval from %s to %s"
const HidePorchCommands = false
Controls whether the Package Orchestration CLI commands are hidden.
Variables ¶
This section is empty.
Functions ¶
func CreateClientWithFlags ¶
func CreateClientWithFlags(flags *genericclioptions.ConfigFlags) (client.Client, error)
func CreateDynamicClient ¶
func CreateDynamicClient(flags *genericclioptions.ConfigFlags) (client.WithWatch, error)
func CreateRESTClient ¶
func CreateRESTClient(flags *genericclioptions.ConfigFlags) (rest.Interface, error)
controller-runtime does not support subresources so we use REST client directly. TODO: Separate Porch clientset into its own module (similar to k8s clientsets) to use it without causing circular reference.
func LastSegment ¶
func UpdatePackageRevisionApproval ¶
func UpdatePackageRevisionApproval(ctx context.Context, client client.Client, pr *porchapi.PackageRevision, new porchapi.PackageRevisionLifecycle) error
Types ¶
This section is empty.